@@ -69,6 +69,7 @@ static translation_string all_strings[] = {
     {TR_HOTKEY_RESIZE_TO_1024, "Zmień rozmiar okna do 1024x768"},
     {TR_HOTKEY_SAVE_SCREENSHOT, "Zapisz zrzut ekranu"},
     {TR_HOTKEY_SAVE_CITY_SCREENSHOT, "Zapisz zrzut ekranu miasta"},
+    {TR_HOTKEY_SAVE_MINIMAP_SCREENSHOT, "Zapisz zrzut ekranu minimapy"},
     {TR_HOTKEY_BUILD_CLONE, "Sklonuj budynek pod kursorem"},
     {TR_HOTKEY_LOAD_FILE, "Wczytaj plik"},
     {TR_HOTKEY_SAVE_FILE, "Zapisz plik"},
@@ -130,10 +131,8 @@ static translation_string all_strings[] = {
     {TR_ADVISOR_DEATHS_LAST_YEAR, "Śmierci w zeszłym roku:"},
     {TR_ADVISOR_TOTAL_POPULATION, "Razem mieszkańców"},
     { TR_CONFIG_TITLE, "Augustus - konfiguracja" },
-    { TR_CONFIG_SHOW_CONSTRUCTION_SIZE, "Pokaż rozmiar budowy przy przeciąganiu budowy" },
     { TR_CONFIG_ROTATE_MANUALLY, "Obróć bramy i łuk triumfalny skrótem klawiszowym" },
     { TR_CONFIG_DRAW_WALKER_WAYPOINTS, "Pokaż punkty docelowe" },
-    { TR_CONFIG_ENABLE_ZOOM, "Włącz powiększanie/pomniejszanie (może być powolne, wymaga więcej pamięci)" },
     { TR_CONFIG_COMPLETE_RATING_COLUMNS, "Pokaż całe kolumny przy niskich poziomach wyników" },
     { TR_CONFIG_GRANDFESTIVAL, "Wielkie festiwale pozwalają na dodatkowe błogosławieństwo" },
     { TR_CONFIG_JEALOUS_GODS, "Wyłącz zazdrość bogów" },
@@ -158,8 +157,6 @@ static translation_string all_strings[] = {
     { TR_CONFIG_MULTIPLE_BARRACKS, "Zezwól na budowę wielu koszar" },
     { TR_CONFIG_NOT_ACCEPTING_WAREHOUSES, "Hurtownie nie akceptują żadnych dóbr przy zbudowaniu" },
     { TR_CONFIG_HOUSES_DONT_EXPAND_INTO_GARDENS, "Domy nie zajmują ogrodów przy powiększaniu" },
-    { TR_BUILDING_ROADBLOCK, "Blokada drogi" },
-    { TR_BUILDING_ROADBLOCK_DESC, "Blokada drogi powstrzymuje wałęsających się mieszkańców." },
     { TR_BUILDING_ARCHITECT_GUILD, "Gildia inżynierów" },
     { TR_BUILDING_ARCHITECT_GUILD_DESC, "Inżynierowie niestrudzenie pracują, by zbudować monumenty ku chwale Rzymu." },
     { TR_BUILDING_GRAND_TEMPLE_ADD_MODULE, "Nadaj epitet świątyni" },
@@ -376,6 +373,9 @@ static translation_string all_strings[] = {
     { TR_ADVISOR_FROM_GRANARIES, "ze spichlerzy" },
     { TR_ADVISOR_KEEP_STOCKPILING, "Nadal zbieraj surowiec" },
     { TR_ADVISOR_MAX_ATTAINABLE_PROSPERITY_IS, "Maksymalny poziom dobrobytu dla tego poziomu mieszkanie jest" },
+    { TR_ADVISOR_POPULATION_AGE, "Wiek" },
+    { TR_ADVISOR_POPULATION_RESIDENTS, "mieszkańców" },
+    { TR_ADVISOR_POPULATION_DWELLERS, "mieszkańców" },
     { TR_ADVISOR_OPEN_TO_IMPORT, "Otwórz drogę handlową na import" },
     { TR_ADVISOR_OPEN_TO_EXPORT, "Otwórz drogę handlową na eksport" },
     { TR_ADVISOR_TRADE_MAX, "Maks" },
@@ -487,8 +487,6 @@ static translation_string all_strings[] = {
     {TR_CARAVANSERAI_SPECIAL_ORDERS_HEADER, "Instrukcje dla Caravanserai"},
     {TR_CITY_MESSAGE_TEXT_COLOSSEUM_WORKING, "Inauguracyjne rozgrwyki w Twoim koloseum się rozpoczęły. Po Twoim rozkazie, ten monument będzie konsekrowany krwią walecznych!" },
     {TR_CITY_MESSAGE_TITLE_COLOSSEUM_WORKING, "Inauguracyjne rozgrwyki" },
-    {TR_CITY_MESSAGE_TEXT_HIPPODROME_COMPLETE, "Hipodrom jest ukończony. Twoi obywatele z niecierpliwością czekają na Twój rozkaz na rozpoczęcie wyścigów! " },
-    {TR_CITY_MESSAGE_TITLE_HIPPODROME_WORKING, "Wyścigi się rozpoczynają" },
     {TR_CITY_MESSAGE_TEXT_NAVAL_GAMES_PLANNING, "Woda ze zbiorników Twojego miasta powoli wypełnia Koloseum. Stolarze zaczynają składać realistyczne miniaturowe statki wojenne, podczas gdy gladiatorzy trenują do walki na wodzie. Wkrótce rozpoczną się Igrzyska Morskie!" },
     {TR_CITY_MESSAGE_TEXT_NAVAL_GAMES_STARTING, "Koloseum stało się sztucznym jeziorem, gdzie gladiatorzy odtwarzają wielkie rzymskie zwycięstwa na morzu. Krew i woda mieszają się, podczas gdy tłum krzyczy z aprobatą. Naumachia - igrzyska morskie - rozpoczęły się!" },
     {TR_CITY_MESSAGE_TEXT_NAVAL_GAMES_ENDING, "Rozpoczyna się długi proces czyszczenia Koloseum, jest ono opróżniane i przygotowywane do normalnego użytku. Twoi obywatele będą mówić o tym wielkim wodnym spektaklu przez wiele lat." },
@@ -520,8 +518,8 @@ static translation_string all_strings[] = {
     {TR_CONFIG_INFINITE, "Bez limitu" },
     {TR_CONFIG_USE_COLOR_CURSORS, "Użyj kolorowych kursorów" },
     {TR_CONFIG_VIDEO_SOUND, "Włącz dźwięk filmów" },
-    {TR_CONFIG_DISABLE_MOUSE_EDGE_SCROLLING, "Wyłącz przewijanie mapy na krawędzi okna"},
     {TR_CONFIG_EFFECTS, "Włącz efekty dzwiękowe"},
+
     {TR_CONFIG_ENABLE_AUDIO, "Włącz dźwięk"},
     {TR_CONFIG_FULLSCREEN, "Pełny ekran"},
     {TR_CONFIG_GAME_SPEED, "Prędkość gry:"},
@@ -535,13 +533,11 @@ static translation_string all_strings[] = {
     {TR_CONFIG_SPEECH, "Włącz mowę"},
     {TR_CONFIG_VIDEO, "Opcje wideo"},
     {TR_CONFIG_VOLUME, "Głośność"},
+    {TR_CONFIG_UI_INVERSE_MAP_DRAG, "Odwróć kierunki przy przeciąganiu mapy prawym przyciskiem" },
+    {TR_CONFIG_UI_MESSAGE_ALERTS, "Pokazuj nowe wiadomości jako ostrzeżenia zamiast wiadomości" },
     {TR_CONFIG_WINDOWED_RESOLUTION, "Rozdzielność w oknie:"},
     {TR_CONFIG_YOU_WILL_LOSE_YOUR_CONFIGS, "Stracisz wszystkie spersonalizowane konfiguracje."},
     {TR_CONFIG_YOU_WILL_LOSE_YOUR_HOTKEYS, "Stracisz wszystkie spersonalizowane skróty klawiszowe."},
-    {TR_CONFIG_ZOOM_COULD_NOT_BE_ENABLED_MESSAGE,
-        "Twój system nie ma wystarczająco pamięci graficznej by zezwolić na zoom.\n"
-        "Zoom nie został włączony."},
-    {TR_CONFIG_ZOOM_COULD_NOT_BE_ENABLED_TITLE, "Zoom nie mógł zostać włączony"},
     {TR_DOCK_SPECIAL_ORDERS_HEADER, "Instrukcje dla docku"},
     {TR_FIGURE_TYPE_BARKEEP, "Barman" },
     {TR_FIGURE_TYPE_BARKEEP_SUPPLIER, "Dostawca tawerny " },
@@ -567,6 +563,8 @@ static translation_string all_strings[] = {
     {TR_RESOURCE_FISH, "Ryby" },
     {TR_SAVEGAME_LARGER_VERSION_TITLE, "Niezgodna wersja stanu gry"},
     {TR_SAVEGAME_LARGER_VERSION_MESSAGE, "Zapisana gra, którą próbujesz załadować, jest zapisana w nowszej wersji Augustusa. \nUaktualnij Augustusa do najnowszej wersji." },
+    {TR_SAVEGAME_NOT_ABLE_TO_SAVE_TITLE, "Nie można zapisać gry" },
+    {TR_SAVEGAME_NOT_ABLE_TO_SAVE_MESSAGE, "Nie można zapisać gry.\nMożliwe, że folder w którym jest zainstalowany Cezar 3 wymaga uprawnień administratora.\nZmień lokalizację folderu Cezara 3 do miejsa, które nie wymaga uprawnień administratora lub uruchom Augustusa jako administrator (Niezalecane)." },
     {TR_SELECT_GAMES_HEADER, "Igrzyska" },
     {TR_SELECT_GAMES_TEXT, "Igrzyska odbędą się w Koloseum, kosztować to będzie Twoje osobiste fundusze i zasoby Twojego miasta ." },
     {TR_SIDEBAR_EXTRA_INVASIONS, "Inwazje" },
@@ -613,6 +611,7 @@ static translation_string all_strings[] = {
     {TR_TOOLTIP_OVERLAY_ARENA_COL_5, "To mieszkanie ma dostęp do koloseum z dwoma widowiskami." },
     {TR_TOOLTIP_OVERLAY_PROBLEMS_CARTPUSHER, "Czeka na pchacza wozu" },
     {TR_TOOLTIP_OVERLAY_PROBLEMS_MOTHBALLED, "Budynek wyłączony" },
+    {TR_TOOLTIP_OVERLAY_PROBLEMS_PLAGUE, "Budynek jest zarażony" },
     {TR_TOOLTIP_OVERLAY_PROBLEMS_NO_RESOURCES, "Nie ma surowców" },
     {TR_TOOLTIP_OVERLAY_PROBLEMS_NO_WATER_ACCESS, "Nie ma dostępu do wody" },
     {TR_TOOLTIP_OVERLAY_PROBLEMS_STRIKE, "Pracownicy strajkują" },
@@ -644,6 +643,11 @@ static translation_string all_strings[] = {
     {TR_WINDOW_ADVISOR_ENTERTAINMENT_UNDERWAY_OG, "Igrzyska Olimpijskie trwają.Święty ogień płonie dzień i noc, gdy sportowcy walczą o nieśmiertelną chwałę." },
     {TR_WINDOW_ADVISOR_ENTERTAINMENT_PREPARING_IG, "Miesiące do Igrzysk Rzymskich:"},
     {TR_WINDOW_ADVISOR_ENTERTAINMENT_UNDERWAY_IG, "Trwają Igrzyska Rzymskie.Każdy uczestnik rozlewa krew, pot i łzy, aby udowodnić, że jest najlepszym Rzymianinem." },
+    {TR_BUILDING_WINDOW_INDUSTRY_EFFICIENCY, "Efektywność:" },
+    {TR_BUILDING_WINDOW_INDUSTRY_EFFICIENCY_TOOLTIP, "Efektywność to stosunek ile budynek wyprodukował do ile mógł wyprodukować poprzedniego roku." },
+    {TR_BUILDING_WINDOW_INDUSTRY_LOW_EFFICIENCY_RAW_MATERIALS, "Ten budynek ma niską efektywność. To może być spowodowane dużą odległością od miejsca przeznaczenia" },
+    {TR_BUILDING_WINDOW_INDUSTRY_LOW_EFFICIENCY_WORKSHOPS, "Ten budynek ma niską efektywność. To  może być spowodowane brakiem ciągłego dostępu do surowców lub dużą odległością od miejsca przeznaczenia." },
+    {TR_BUILDING_WINDOW_INDUSTRY_WHARF_AVERAGE_CATCH, "Średni miesięczny połów:" },
     {TR_WINDOW_ADVISOR_ENTERTAINMENT_TAVERN_COVERAGE, "Tawerny" },
     {TR_WINDOW_ADVISOR_FINANCE_INTEREST_TRIBUTE, "Trybut/oprocentowanie"},
     {TR_WINDOW_ADVISOR_TOURISM, "Rozmaite"},
@@ -651,7 +655,6 @@ static translation_string all_strings[] = {
     {TR_WINDOW_BUILDING_ARENA_BOTH_SHOWS, "Na tej arenie odbywają się gladiatorzy i polowania na zwierzęta, ku uciesze mieszkańców." },
     {TR_WINDOW_BUILDING_ARENA_NEEDS_LIONS, "Regularne pokazy gladiatorów zapewniają rozrywkę tłumowi, ale lwy podniosłyby poziom widowiska." },
     {TR_WINDOW_BUILDING_ARENA_NEEDS_GLADIATORS, "Głodne bestie grasują po arenie w poszukiwaniu zdobyczy, ale brak wyszkolonych gladiatorów sprawia, że na krótkie pokazy." },
-    {TR_WINDOW_BUILDING_ARENA_NO_SHOWS, "Na tej arenie nie ma ani lwów, ani gladiatorów i nie zapewnia ona zbyt wiele rozrywki." },
     {TR_WINDOW_BUILDING_GAMES_REMAINING_DURATION, "Wielkie igrzyska będą kontynuowane przez" }, // ...XX Days, 
     {TR_WINDOW_BUILDING_GOVERNMENT_LARGE_STATUE_WATER_WARNING, "Ten posąg wyglądałby jeszcze wspanialej z działającą fontanną.Zapewnij mu dostęp do wody." },
     {TR_WINDOW_BUILDING_INFO_WARNING_NO_MONUMENT_ROAD_ACCESS, "Ten plac budowy pomnika nie ma dostępu do drogi i nie może przyjmować materiałów. Połącz drogę z jednym ze środkowych kafelków."},
@@ -683,6 +686,7 @@ static translation_string all_strings[] = {
     {TR_HOTKEY_PASTE_SETTINGS, "Wklej ustawienia budynku" },
     {TR_WINDOW_ADVISOR_RELIGION_LARARIUMS, "Lararia w mieście" },
     {TR_WINDOW_RACE_BET_BUTTON, "Postaw na konia" },
+    {TR_WINDOW_RACE_YOUR_BET, "Postawiono" },
     {TR_WINDOW_IN_PROGRESS_BET_BUTTON, "Wyścig w toku..." },
     {TR_WINDOW_RACE_BET_TITLE, "Postaw zakład na konia" },
     {TR_WINDOW_RACE_BET_AMOUNT, "Stawka" },
@@ -723,8 +727,80 @@ static translation_string all_strings[] = {
     {TR_TOOLTIP_BUTTON_STOCKPILING_OFF, "Wyłącz dostawy do magazynu" },
     {TR_TOOLTIP_BUTTON_ACCEPT_WORKERS, "Wstrzymaj dostarczanie zasobów z magazynu" },
     {TR_WINDOW_BUILDING_ARENA_CLOSED, "Arena jest zamknięta. Ptaki zakładają gniazda w opuszczonych siedzeniach." },
-    {TR_CONFIG_DIGIT_SEPARATOR, "Separate digits"},
-
+    {TR_CONFIG_DIGIT_SEPARATOR, "Odstęp między cyframi"},
+    {TR_WARNING_SCREENSHOT_SAVED, "Zapisano zrzut ekranu: "}, 
+    {TR_TOOLTIP_OVERLAY_PROBLEMS_NO_LABOR, "Brak pracowników" },
+    {TR_WINDOW_BUILDING_DISTRIBUTION_GRANARY_CART_PUSHER_GETTING, "Pchacz wozu jest w drodze, aby odebrać żywność z innego spichlerza." },
+    {TR_WINDOW_BUILDING_DISTRIBUTION_CART_PUSHER_RETURNING_WITH, "Pchacz wozu wraca z dostawą." },
+    {TR_BUTTON_YEARLY_AUTOSAVE_OFF, "Roczny autozapis WYŁ" },
+    {TR_BUTTON_YEARLY_AUTOSAVE_ON, "Roczny autozapis WŁ" },
+    {TR_BUILDING_DOCK_PLAGUE_DESC, "Statek handlowy przywiózł zarazę. Dok jest w kwarantanncie do czasu odkażenia." },
+    {TR_BUILDING_GRANARY_PLAGUE_DESC, "Zarażony pracownik sprowadził tutaj zarazę. Ten spichlerz jest w kwarantannie do czasu odkażenia." },
+    {TR_BUILDING_WAREHOUSE_PLAGUE_DESC, "Zarażony pracownik sprowadził tutaj zarazę. Ten magazyn jest w kwarantannie do czasu odkażenia." },
+    {TR_BUILDING_HOUSE_DISEASE_DESC, "Wybuchła epidemia! Z powodu braku wystarczającej ochrony zdrowotnej, mieszkańcy tego domostwa zmarli. Domostwo jest zamknięte do czasu odkażenia" },
+    {TR_BUILDING_FUMIGATION_DESC, "Ten budynek jest oczyszczany z zarazy. Odymianie powinno potrwać kilka dni." },
+    {TR_OVERLAY_SICKNESS, "Choroba" },
+    {TR_ADVISOR_SICKNESS_LEVEL_LOW, "Choroby są rzadkim zjawiskiem w tym mieście i handel funkcjonuje bez zarzutu. Wysokie standardy higieny efektywnie powstrzymują epidemię przed rozprzestrzenianiem."},
+    {TR_ADVISOR_SICKNESS_LEVEL_MEDIUM, "W mieście występują choroby zakaźne, ale sytuacja jest pod kontrolą. Wysoki poziom opieki zdrowotnej dopilnuje żeby handel nie został zakłócony." },
+    {TR_ADVISOR_SICKNESS_LEVEL_HIGH, "Choroby zakaźne rozprzestrzeniają się po mieście. Jeśli sytuacja nie zostanie szybko zażegnana, handel może ucierpieć. Potrzebne jest więcej klinik i szpitali aby skutecznie powstrzymać epidemię przed rozprzestrzenieniem się do innych obszarów." },
+    {TR_ADVISOR_SICKNESS_LEVEL_PLAGUE, "Zaraza dotarła do miasta! Wielu obywateli zachorowało i handel jest poważnie ograniczony. Ostatni dostępni lekarze i chirurdzy zostali zaciągnięci do służb odkażających w najbardziej ucierpiałych obszarach. Poważne kroki muszą zostać podjęte!" },
+    {TR_TOOLTIP_OVERLAY_SICKNESS_LOW, "Niewiele chorób" },
+    {TR_TOOLTIP_OVERLAY_SICKNESS_MEDIUM, "Niewiele chorób zakaźnych" },
+    {TR_TOOLTIP_OVERLAY_SICKNESS_HIGH, "Wiele chorób zakaźnych się rozprzestrzenia" },
+    {TR_TOOLTIP_OVERLAY_SICKNESS_PLAGUE, "Zaraza nęka miasto" },
+    {TR_CITY_MESSAGE_TITLE_SICKNESS, "Zaraza w mieście" },
+    {TR_CITY_MESSAGE_TEXT_SICKNESS, "Zaraza wybuchła w mieście! Budynek jest w kwarantannie i lekarze lub chirurdzy zostali zaciągnięci do służby przy odkażaniu." },
+    {TR_FIGURES_CARTPUSHER_GOING_TO_ROME, "Dostarcza żądanie do Rzymu" },
+    {TR_CITY_WARNING_DATA_COPY_SUCCESS, "Ustawienia skopiowane" },
+    {TR_CITY_WARNING_DATA_COPY_NOT_SUPPORTED, "Nie można skopiować ustawień tego budynku" },
+    {TR_CITY_WARNING_DATA_PASTE_SUCCESS, "Ustawienia wklejone" },
+    {TR_CITY_WARNING_DATA_PASTE_NOT_SUPPORTED, "Nie można wkleić" },
+    {TR_HOTKEY_SHOW_OVERLAY_FOOD_STOCKS, "Widok zapasów żywności" },
+    {TR_HOTKEY_SHOW_OVERLAY_ENTERTAINMENT, "Widok rozrywki" },
+    {TR_HOTKEY_SHOW_OVERLAY_SCHOOL, "Widok szkół" },
+    {TR_HOTKEY_SHOW_OVERLAY_LIBRARY, "Widok bibliotek" },
+    {TR_HOTKEY_SHOW_OVERLAY_ACADEMY, "Widok akademii" },
+    {TR_HOTKEY_SHOW_OVERLAY_BARBER, "Widok fryzjerów" },
+    {TR_HOTKEY_SHOW_OVERLAY_BATHHOUSE, "Widok łaźni" },
+    {TR_HOTKEY_SHOW_OVERLAY_CLINIC, "Widok klinik" },
+    {TR_HOTKEY_SHOW_OVERLAY_SICKNESS, "Widok chorób" },
+    {TR_HOTKEY_SHOW_OVERLAY_TAX_INCOME, "Widok podatków" },
+    {TR_HOTKEY_SHOW_OVERLAY_RELIGION, "Widok religii" },
+    {TR_HOTKEY_SHOW_OVERLAY_ROADS, "Widok dróg" },
+    {TR_HOTKEY_ROTATE_MAP_NORTH, "Obróć mapę na północ" },
+    {TR_HOTKEY_BUILD_WHEAT_FARM, "Farma zboża" },
+    {TR_HOTKEY_SHOW_MESSAGES, "Pokaż wiadomości" },
+    {TR_HOTKEY_SHOW_EMPIRE_MAP, "Pokaż mapę imperium" },
+    {TR_TOGGLE_GRID, "Przełącz siatkę mapy" },
+    {TR_CONFIG_UI_SHOW_GRID, "Pokaż siatkę mapy" },
+    {TR_CONFIG_UI_SHOW_PARTIAL_GRID_AROUND_CONSTRUCTION, "Pokaż częściową siatkę mapy przy budowaniu" },
+    {TR_OUT_OF_MONEY, "Brak pieniędzy" },
+    {TR_CITY_MESSAGE_TITLE_EMPERORS_WRATH, "Gniew Cezara" },
+    {TR_CITY_MESSAGE_TEXT_EMPERORS_WRATH, "Wypadłeś z łask Cezara zatem zarządził Twoje aresztowanie. Jeżeli nie dasz rady przywrócić łaski Cezara, jego elitarni legioniści niedługo zaatakują Twoje miasto" },
+    {TR_BUILDING_ACADEMY_UPGRADE_DESC, "Akademia jest sprawna. Rozwój okolicy umożliwił Twoim obywatelom poszerzenie akademii, zapewniając więcej przestrzeni na przemówienia i prace badawcze" },
+    {TR_BUILDING_PALISADE_GATE, "Brama palisady" },
+    {TR_BUILDING_PALISADE_GATE_DESC, "Ta wąska drewniana brama kontroluje ruch obywateli na drugą stronę fortyfikacji." },
+    {TR_SAVE_DIALOG_INVALID_FILE, "Niewłaściwy plik" },
+    {TR_SAVE_DIALOG_SELECT_FILE, "Wybierz plik" },
+    {TR_SAVE_DIALOG_FUNDS, "Fundusze:" },
+    {TR_SAVE_DIALOG_POPULATION, "Populacja:" },
+    {TR_SAVE_DIALOG_DATE, "Data:" },
+    {TR_SAVE_DIALOG_CUSTOM_SCENARIO, "Dodatkowa misja" },
+    {TR_SAVE_DIALOG_FIRST_MISSION, "Pierwsze zadanie" },
+    {TR_SAVE_DIALOG_MISSION, "Zadanie" },
+    {TR_SAVE_DIALOG_MILITARY, "Wojskowe" },
+    {TR_SAVE_DIALOG_PEACEFUL, "Pokojowe" },
+    {TR_CITY_MESSAGE_TITLE_MARS_MINOR_CURSE_PREVENTED, "Gniew Marsa" },
+    {TR_CITY_MESSAGE_TEXT_MARS_MINOR_CURSE_PREVENTED, "Mars jest wściekły! Nie musimy się wiele obawiać w tej pokojowej prowincji, ale ten pokój nie będzie trwać wiecznie!" },
+    {TR_TOOLTIP_MONUMENT_PHASE, " faza. " },
+    {TR_TOOLTIP_MONUMENT_PHASES, " faz. " },
+    {TR_TOOLTIP_MONUMENT_RESOURCE_REQUIREMENTS, "Potrzebne materiały:\n" },
+    {TR_BUILDING_GLADIATOR_STATUE, "Posąg gladiatora" },
+    {TR_ADVISOR_NO_ACTIVE_COLOSSEUM, "Brak czynnego koloseum w mieście" },
+    {TR_ADVISOR_ACTIVE_COLOSSEUM, "Miasto posiada czynne koloseum" },
+    {TR_ADVISOR_NO_ACTIVE_HIPPODROME, "Brak czynnego hipodromu" },
+    {TR_ADVISOR_ACTIVE_HIPPODROME, "Miasto posiada czynny hipodrom" },
+    {TR_WINDOW_ADVISOR_EDUCATION_MISSION_POSTS, "Misje" }
 };
 
 void translation_polish(const translation_string **strings, int *num_strings)
